<?php
require_once 'config.php';

// Handle Telegram auth callback
if (isset($_GET['tgAuth'])) {
    $auth_data = $_GET;
    
    // Check required fields
    $check_hash = $auth_data['hash'];
    unset($auth_data['hash']);
    
    $data_check_arr = [];
    foreach ($auth_data as $key => $value) {
        $data_check_arr[] = $key . '=' . $value;
    }
    
    sort($data_check_arr);
    $data_check_string = implode("\n", $data_check_arr);
    $secret_key = hash('sha256', TELEGRAM_BOT_TOKEN, true);
    $hash = hash_hmac('sha256', $data_check_string, $secret_key);
    
    if (strcmp($hash, $check_hash) !== 0) {
        die('Data is NOT from Telegram');
    }
    
    if ((time() - $auth_data['auth_date']) > 86400) {
        die('Data is outdated');
    }
    
    // Authentication successful
    $telegramUser = [
        'id' => $auth_data['id'],
        'first_name' => $auth_data['first_name'] ?? '',
        'last_name' => $auth_data['last_name'] ?? '',
        'username' => $auth_data['username'] ?? '',
        'photo_url' => $auth_data['photo_url'] ?? '',
        'auth_date' => $auth_data['auth_date']
    ];
    
    // Store user in session
    $_SESSION['telegram_user'] = $telegramUser;
    
    // Check if user exists in database
    try {
        $stmt = $pdo->prepare("SELECT * FROM users WHERE telegram_id = ?");
        $stmt->execute([$telegramUser['id']]);
        $user = $stmt->fetch(PDO::FETCH_ASSOC);
        
        if (!$user) {
            // Create new user
            $fullName = trim($telegramUser['first_name'] . ' ' . ($telegramUser['last_name'] ?? ''));
            $referralCode = generateReferralCode();
            
            $stmt = $pdo->prepare("
                INSERT INTO users (telegram_id, username, full_name, referral_code, last_login)
                VALUES (?, ?, ?, ?, NOW())
            ");
            $stmt->execute([
                $telegramUser['id'],
                $telegramUser['username'],
                $fullName,
                $referralCode
            ]);
            
            // Check if user came from referral
            if (isset($_COOKIE['ref_code'])) {
                $refCode = $_COOKIE['ref_code'];
                $stmt = $pdo->prepare("SELECT id FROM users WHERE referral_code = ?");
                $stmt->execute([$refCode]);
                $referrer = $stmt->fetch(PDO::FETCH_ASSOC);
                
                if ($referrer) {
                    // Update referred_by
                    $stmt = $pdo->prepare("UPDATE users SET referred_by = ? WHERE telegram_id = ?");
                    $stmt->execute([$refCode, $telegramUser['id']]);
                    
                    // Add referral bonus to referrer
                    $stmt = $pdo->prepare("
                        INSERT INTO earnings (user_id, amount, source, description)
                        VALUES (?, ?, 'referral', ?)
                    ");
                    $stmt->execute([
                        $referrer['id'],
                        REFERRAL_REWARD,
                        'Referral bonus for ' . $telegramUser['username']
                    ]);
                    
                    // Update referrer's balance
                    $stmt = $pdo->prepare("UPDATE users SET balance = balance + ? WHERE id = ?");
                    $stmt->execute([REFERRAL_REWARD, $referrer['id']]);
                }
            }
        } else {
            // Update last login
            $stmt = $pdo->prepare("UPDATE users SET last_login = NOW() WHERE telegram_id = ?");
            $stmt->execute([$telegramUser['id']]);
        }
    } catch(PDOException $e) {
        // Log error but continue
        error_log("Database error: " . $e->getMessage());
    }
    
    // Redirect to home page
    header("Location: index.php");
    exit();
}

// Generate Telegram login widget
$bot_username = 'YOUR_TELEGRAM_BOT_USERNAME'; // Replace with your bot username
$redirect_url = urlencode('http://'.$_SERVER['HTTP_HOST'].'/auth.php?tgAuth=1');
$telegramAuthUrl = "https://telegram.org/widget/login?bot_id=$bot_username&origin=$redirect_url";

// Redirect to Telegram auth
header("Location: $telegramAuthUrl");
exit();
?>