<?php
require_once 'config.php';

// Check if user is logged in
if (!isset($_SESSION['telegram_user'])) {
    header('Content-Type: application/json');
    echo json_encode(['success' => false, 'message' => 'Not logged in']);
    exit();
}

// Check if task ID is provided
if (!isset($_POST['task_id'])) {
    header('Content-Type: application/json');
    echo json_encode(['success' => false, 'message' => 'Task ID required']);
    exit();
}

$telegramId = $_SESSION['telegram_user']['id'];
$taskId = intval($_POST['task_id']);

try {
    // Get user and task data
    $stmt = $pdo->prepare("SELECT id FROM users WHERE telegram_id = ?");
    $stmt->execute([$telegramId]);
    $user = $stmt->fetch(PDO::FETCH_ASSOC);
    
    if (!$user) {
        header('Content-Type: application/json');
        echo json_encode(['success' => false, 'message' => 'User not found']);
        exit();
    }
    
    $stmt = $pdo->prepare("SELECT * FROM tasks WHERE id = ?");
    $stmt->execute([$taskId]);
    $task = $stmt->fetch(PDO::FETCH_ASSOC);
    
    if (!$task) {
        header('Content-Type: application/json');
        echo json_encode(['success' => false, 'message' => 'Task not found']);
        exit();
    }
    
    // Check if user has already completed this task today
    $today = date('Y-m-d');
    $stmt = $pdo->prepare("
        SELECT COUNT(*) as count 
        FROM user_tasks 
        WHERE user_id = ? AND task_id = ? AND DATE(completion_date) = ?
    ");
    $stmt->execute([$user['id'], $taskId, $today]);
    $completedCount = $stmt->fetch(PDO::FETCH_ASSOC)['count'];
    
    if ($completedCount >= $task['daily_limit']) {
        header('Content-Type: application/json');
        echo json_encode(['success' => false, 'message' => 'Daily limit reached for this task']);
        exit();
    }
    
    // Start transaction
    $pdo->beginTransaction();
    
    // Record task completion
    $stmt = $pdo->prepare("
        INSERT INTO user_tasks (user_id, task_id)
        VALUES (?, ?)
    ");
    $stmt->execute([$user['id'], $taskId]);
    
    // Record earnings
    $stmt = $pdo->prepare("
        INSERT INTO earnings (user_id, amount, source, description)
        VALUES (?, ?, 'task', ?)
    ");
    $stmt->execute([
        $user['id'],
        $task['reward'],
        'Completed task: ' . $task['title']
    ]);
    
    // Update user balance
    $stmt = $pdo->prepare("
        UPDATE users SET balance = balance + ? WHERE id = ?
    ");
    $stmt->execute([$task['reward'], $user['id']]);
    
    // Commit transaction
    $pdo->commit();
    
    header('Content-Type: application/json');
    echo json_encode([
        'success' => true,
        'amount' => formatCurrency($task['reward']),
        'message' => 'Task completed successfully'
    ]);
    
} catch(PDOException $e) {
    $pdo->rollBack();
    header('Content-Type: application/json');
    echo json_encode(['success' => false, 'message' => 'Database error: ' . $e->getMessage()]);
}
?>