<?php
require_once 'config.php';

// Check if user is logged in
if (!isset($_SESSION['telegram_user'])) {
    header("Location: index.php");
    exit();
}

$telegramId = $_SESSION['telegram_user']['id'];

// Get user data
try {
    $stmt = $pdo->prepare("SELECT * FROM users WHERE telegram_id = ?");
    $stmt->execute([$telegramId]);
    $user = $stmt->fetch(PDO::FETCH_ASSOC);
    
    if (!$user) {
        header("Location: logout.php");
        exit();
    }
    
    // Get balance
    $balance = $user['balance'];
    
    // Get today's ad views
    $today = date('Y-m-d');
    $stmt = $pdo->prepare("
        SELECT COUNT(*) as count 
        FROM earnings 
        WHERE user_id = ? AND source = 'ad' AND DATE(earn_date) = ?
    ");
    $stmt->execute([$user['id'], $today]);
    $todayAds = $stmt->fetch(PDO::FETCH_ASSOC)['count'] ?? 0;
    
    // Daily ad limit
    $dailyAdLimit = 10;
    $adsRemaining = max(0, $dailyAdLimit - $todayAds);
    
} catch(PDOException $e) {
    die("Database error: " . $e->getMessage());
}

// Handle ad view
if (isset($_GET['view_ad'])) {
    if ($adsRemaining <= 0) {
        $_SESSION['error'] = "You've reached your daily ad limit. Come back tomorrow!";
        header("Location: earn.php");
        exit();
    }
    
    try {
        // Record earnings
        $stmt = $pdo->prepare("
            INSERT INTO earnings (user_id, amount, source, description)
            VALUES (?, ?, 'ad', 'Ad view reward')
        ");
        $stmt->execute([$user['id'], AD_REWARD]);
        
        // Update balance
        $stmt = $pdo->prepare("UPDATE users SET balance = balance + ? WHERE id = ?");
        $stmt->execute([AD_REWARD, $user['id']]);
        
        $_SESSION['success'] = "You earned " . formatCurrency(AD_REWARD) . " for watching an ad!";
        header("Location: earn.php");
        exit();
    } catch(PDOException $e) {
        $_SESSION['error'] = "Error processing your reward. Please try again.";
        header("Location: earn.php");
        exit();
    }
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Earn Money - Telegram Username Bot</title>
    <link href="https://fonts.googleapis.com/css2?family=Roboto:wght@300;400;500;700&display=swap" rel="stylesheet">
    <style>
        * {
            margin: 0;
            padding: 0;
            box-sizing: border-box;
            font-family: 'Roboto', sans-serif;
        }
        body {
            background-color: #f5f5f5;
            color: #333;
        }
        .container {
            max-width: 500px;
            margin: 0 auto;
            background: white;
            min-height: 100vh;
            position: relative;
        }
        .header {
            background-color: #0088cc;
            color: white;
            padding: 15px;
            text-align: center;
        }
        .logo {
            font-size: 20px;
            font-weight: bold;
        }
        .main-content {
            padding: 15px;
        }
        .balance-section {
            background: white;
            border-radius: 10px;
            padding: 15px;
            margin-bottom: 15px;
            box-shadow: 0 2px 5px rgba(0,0,0,0.1);
            text-align: center;
        }
        .balance-amount {
            font-size: 24px;
            font-weight: bold;
            color: #0088cc;
            margin: 10px 0;
        }
        .ad-section {
            background: white;
            border-radius: 10px;
            padding: 15px;
            margin-bottom: 15px;
            box-shadow: 0 2px 5px rgba(0,0,0,0.1);
            text-align: center;
        }
        .ad-title {
            font-weight: 500;
            margin-bottom: 10px;
        }
        .ad-description {
            color: #666;
            margin-bottom: 15px;
        }
        .ad-reward {
            color: #0088cc;
            font-weight: 500;
            margin-bottom: 15px;
        }
        .ad-limit {
            font-size: 14px;
            color: #666;
            margin-bottom: 15px;
        }
        .watch-ad-btn {
            background-color: #0088cc;
            color: white;
            border: none;
            padding: 15px;
            border-radius: 5px;
            font-weight: 500;
            cursor: pointer;
            display: block;
            width: 100%;
            font-size: 16px;
        }
        .watch-ad-btn:disabled {
            background-color: #ccc;
            cursor: not-allowed;
        }
        .task-section {
            background: white;
            border-radius: 10px;
            padding: 15px;
            margin-bottom: 15px;
            box-shadow: 0 2px 5px rgba(0,0,0,0.1);
        }
        .task-header {
            display: flex;
            justify-content: space-between;
            margin-bottom: 10px;
        }
        .task-title {
            font-weight: 500;
        }
        .task-item {
            display: flex;
            justify-content: space-between;
            padding: 10px 0;
            border-bottom: 1px solid #eee;
        }
        .task-name {
            flex: 1;
        }
        .task-reward {
            color: #0088cc;
            font-weight: 500;
        }
        .task-complete-btn {
            background-color: #0088cc;
            color: white;
            border: none;
            padding: 5px 10px;
            border-radius: 5px;
            font-size: 12px;
            cursor: pointer;
        }
        .message {
            padding: 10px;
            margin-bottom: 15px;
            border-radius: 5px;
            text-align: center;
        }
        .success {
            background-color: #d4edda;
            color: #155724;
        }
        .error {
            background-color: #f8d7da;
            color: #721c24;
        }
        .footer {
            position: fixed;
            bottom: 0;
            width: 100%;
            max-width: 500px;
            background-color: #0088cc;
            display: flex;
            justify-content: space-around;
            padding: 10px 0;
        }
        .footer-btn {
            color: white;
            text-decoration: none;
            text-align: center;
            font-size: 12px;
        }
        .footer-icon {
            font-size: 20px;
            margin-bottom: 5px;
        }
    </style>
</head>
<body>
    <div class="container">
        <div class="header">
            <div class="logo">Earn Money</div>
        </div>
        
        <div class="main-content">
            <?php if (isset($_SESSION['success'])): ?>
                <div class="message success"><?php echo $_SESSION['success']; unset($_SESSION['success']); ?></div>
            <?php endif; ?>
            
            <?php if (isset($_SESSION['error'])): ?>
                <div class="message error"><?php echo $_SESSION['error']; unset($_SESSION['error']); ?></div>
            <?php endif; ?>
            
            <div class="balance-section">
                <div>Available Balance</div>
                <div class="balance-amount"><?php echo formatCurrency($balance); ?></div>
            </div>
            
            <div class="ad-section">
                <div class="ad-title">Watch Ads & Earn Money</div>
                <div class="ad-description">Watch short video ads and earn money for each view</div>
                <div class="ad-reward">Earn <?php echo formatCurrency(AD_REWARD); ?> per ad</div>
                <div class="ad-limit">Today: <?php echo $todayAds; ?> of <?php echo $dailyAdLimit; ?> ads watched</div>
                
                <?php if ($adsRemaining > 0): ?>
                    <button class="watch-ad-btn" onclick="window.open('<?php echo MONETAG_AD_URL; ?>', '_blank'); setTimeout(function(){ window.location.href='earn.php?view_ad=1'; }, 30000);">
                        Watch Ad & Earn <?php echo formatCurrency(AD_REWARD); ?>
                    </button>
                <?php else: ?>
                    <button class="watch-ad-btn" disabled>
                        Daily Limit Reached
                    </button>
                <?php endif; ?>
            </div>
            
            <div class="task-section">
                <div class="task-header">
                    <div class="task-title">Complete Tasks</div>
                    <div>Rewards</div>
                </div>
                
                <div class="task-item">
                    <div class="task-name">Daily Login Bonus</div>
                    <div class="task-reward"><?php echo formatCurrency(0.10); ?></div>
                    <button class="task-complete-btn">Complete</button>
                </div>
                
                <div class="task-item">
                    <div class="task-name">Invite Friends</div>
                    <div class="task-reward"><?php echo formatCurrency(0.50); ?></div>
                    <button class="task-complete-btn">Complete</button>
                </div>
                
                <div class="task-item">
                    <div class="task-name">Watch 5 Ads</div>
                    <div class="task-reward"><?php echo formatCurrency(0.20); ?></div>
                    <button class="task-complete-btn">Complete</button>
                </div>
            </div>
        </div>
        
        <div class="footer">
            <a href="index.php" class="footer-btn">
                <div class="footer-icon">🏠</div>
                <div>Home</div>
            </a>
            <a href="earn.php" class="footer-btn">
                <div class="footer-icon">💰</div>
                <div>Earn</div>
            </a>
            <a href="withdraw.php" class="footer-btn">
                <div class="footer-icon">💳</div>
                <div>Withdraw</div>
            </a>
            <a href="profile.php" class="footer-btn">
                <div class="footer-icon">👤</div>
                <div>Profile</div>
            </a>
        </div>
    </div>
</body>
</html>