<?php
require_once 'config.php';

// Check if user is logged in (Telegram auth)
$loggedIn = isset($_SESSION['telegram_user']);

// Get user data if logged in
$user = null;
$balance = 0.00;
$totalEarnings = 0.00;
$adsWatched = 0;

if ($loggedIn) {
    $telegramId = $_SESSION['telegram_user']['id'];
    
    try {
        // Get user data
        $stmt = $pdo->prepare("SELECT * FROM users WHERE telegram_id = ?");
        $stmt->execute([$telegramId]);
        $user = $stmt->fetch(PDO::FETCH_ASSOC);
        
        if ($user) {
            // Get balance
            $balance = $user['balance'];
            
            // Get total earnings
            $stmt = $pdo->prepare("SELECT SUM(amount) as total FROM earnings WHERE user_id = ?");
            $stmt->execute([$user['id']]);
            $totalEarnings = $stmt->fetch(PDO::FETCH_ASSOC)['total'] ?? 0;
            
            // Get ads watched
            $stmt = $pdo->prepare("SELECT COUNT(*) as count FROM earnings WHERE user_id = ? AND source = 'ad'");
            $stmt->execute([$user['id']]);
            $adsWatched = $stmt->fetch(PDO::FETCH_ASSOC)['count'] ?? 0;
        }
    } catch(PDOException $e) {
        // Handle error
    }
}

// Get today's tasks
$todayTasks = [];
if ($loggedIn && $user) {
    try {
        $today = date('Y-m-d');
        $stmt = $pdo->prepare("
            SELECT t.*, 
                   (SELECT COUNT(*) FROM user_tasks WHERE user_id = ? AND task_id = t.id AND DATE(completion_date) = ?) as completed_count
            FROM tasks t
            WHERE t.is_active = TRUE
        ");
        $stmt->execute([$user['id'], $today]);
        $todayTasks = $stmt->fetchAll(PDO::FETCH_ASSOC);
    } catch(PDOException $e) {
        // Handle error
    }
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Telegram Username Bot - Earn Money</title>
    <link href="https://fonts.googleapis.com/css2?family=Roboto:wght@300;400;500;700&display=swap" rel="stylesheet">
    <style>
        * {
            margin: 0;
            padding: 0;
            box-sizing: border-box;
            font-family: 'Roboto', sans-serif;
        }
        body {
            background-color: #f5f5f5;
            color: #333;
        }
        .container {
            max-width: 500px;
            margin: 0 auto;
            background: white;
            min-height: 100vh;
            position: relative;
        }
        .header {
            background-color: #0088cc;
            color: white;
            padding: 15px;
            text-align: center;
            position: relative;
        }
        .logo {
            font-size: 20px;
            font-weight: bold;
        }
        .contact-info {
            font-size: 12px;
            margin-top: 5px;
        }
        .main-content {
            padding: 15px;
        }
        .welcome-section, .earn-section {
            background: white;
            border-radius: 10px;
            padding: 15px;
            margin-bottom: 15px;
            box-shadow: 0 2px 5px rgba(0,0,0,0.1);
            display: flex;
            align-items: center;
        }
        .section-icon {
            width: 50px;
            height: 50px;
            background-color: #e6f7ff;
            border-radius: 50%;
            display: flex;
            align-items: center;
            justify-content: center;
            margin-right: 15px;
            color: #0088cc;
            font-size: 24px;
        }
        .section-content {
            flex: 1;
        }
        .section-title {
            font-weight: 500;
            margin-bottom: 5px;
        }
        .section-description {
            font-size: 14px;
            color: #666;
        }
        .earn-now-btn {
            background-color: #0088cc;
            color: white;
            border: none;
            padding: 10px 15px;
            border-radius: 5px;
            font-weight: 500;
            cursor: pointer;
            display: block;
            width: 100%;
            margin-top: 10px;
        }
        .balance-section {
            background: white;
            border-radius: 10px;
            padding: 15px;
            margin-bottom: 15px;
            box-shadow: 0 2px 5px rgba(0,0,0,0.1);
            text-align: center;
        }
        .balance-amount {
            font-size: 24px;
            font-weight: bold;
            color: #0088cc;
            margin: 10px 0;
        }
        .task-section {
            background: white;
            border-radius: 10px;
            padding: 15px;
            margin-bottom: 15px;
            box-shadow: 0 2px 5px rgba(0,0,0,0.1);
        }
        .task-header {
            display: flex;
            justify-content: space-between;
            margin-bottom: 10px;
        }
        .task-title {
            font-weight: 500;
        }
        .task-item {
            display: flex;
            justify-content: space-between;
            padding: 10px 0;
            border-bottom: 1px solid #eee;
        }
        .task-name {
            flex: 1;
        }
        .task-reward {
            color: #0088cc;
            font-weight: 500;
        }
        .task-complete-btn {
            background-color: #0088cc;
            color: white;
            border: none;
            padding: 5px 10px;
            border-radius: 5px;
            font-size: 12px;
            cursor: pointer;
        }
        .footer {
            position: fixed;
            bottom: 0;
            width: 100%;
            max-width: 500px;
            background-color: #0088cc;
            display: flex;
            justify-content: space-around;
            padding: 10px 0;
        }
        .footer-btn {
            color: white;
            text-decoration: none;
            text-align: center;
            font-size: 12px;
        }
        .footer-icon {
            font-size: 20px;
            margin-bottom: 5px;
        }
        .refer-section {
            background: white;
            border-radius: 10px;
            padding: 15px;
            margin-bottom: 15px;
            box-shadow: 0 2px 5px rgba(0,0,0,0.1);
            text-align: center;
        }
        .refer-btn {
            background-color: #8e44ad;
            color: white;
            border: none;
            padding: 10px 15px;
            border-radius: 5px;
            font-weight: 500;
            cursor: pointer;
            display: block;
            width: 100%;
            margin-top: 10px;
        }
    </style>
</head>
<body>
    <div class="container">
        <div class="header">
            <div class="logo">Telegram Username Bot</div>
            <div class="contact-info">Contact: support@telegramusernamebot.com</div>
        </div>
        
        <div class="main-content">
            <?php if (!$loggedIn): ?>
                <div class="welcome-section">
                    <div class="section-icon">👋</div>
                    <div class="section-content">
                        <div class="section-title">Welcome to Telegram Username Bot</div>
                        <div class="section-description">Login with your Telegram account to start earning money</div>
                        <button class="earn-now-btn" onclick="window.location.href='auth.php'">Login with Telegram</button>
                    </div>
                </div>
            <?php else: ?>
                <div class="welcome-section">
                    <div class="section-icon">👤</div>
                    <div class="section-content">
                        <div class="section-title">Welcome, <?php echo htmlspecialchars($user['full_name'] ?? 'User'); ?></div>
                        <div class="section-description">@<?php echo htmlspecialchars($user['username'] ?? ''); ?></div>
                    </div>
                </div>
                
                <div class="balance-section">
                    <div>Available Balance</div>
                    <div class="balance-amount"><?php echo formatCurrency($balance); ?></div>
                    <div>Total Earnings: <?php echo formatCurrency($totalEarnings); ?></div>
                    <div>Total Ads Watched: <?php echo $adsWatched; ?></div>
                </div>
                
                <div class="earn-section">
                    <div class="section-icon">💰</div>
                    <div class="section-content">
                        <div class="section-title">Start Earning Now</div>
                        <div class="section-description">Watch ads and complete tasks to earn money</div>
                        <button class="earn-now-btn" onclick="window.location.href='earn.php'">Start Earning</button>
                    </div>
                </div>
                
                <div class="task-section">
                    <div class="task-header">
                        <div class="task-title">Today's Tasks</div>
                        <div>Rewards</div>
                    </div>
                    
                    <?php foreach ($todayTasks as $task): ?>
                        <div class="task-item">
                            <div class="task-name"><?php echo htmlspecialchars($task['title']); ?></div>
                            <div class="task-reward"><?php echo formatCurrency($task['reward']); ?></div>
                            <button class="task-complete-btn" onclick="completeTask(<?php echo $task['id']; ?>)">
                                <?php echo ($task['completed_count'] > 0) ? 'Completed' : 'Complete'; ?>
                            </button>
                        </div>
                    <?php endforeach; ?>
                    
                    <?php if (empty($todayTasks)): ?>
                        <div style="text-align: center; padding: 10px; color: #666;">No tasks available today</div>
                    <?php endif; ?>
                </div>
                
                <div class="refer-section">
                    <div class="section-title">Refer Friends & Earn More</div>
                    <div class="section-description">Get <?php echo formatCurrency(REFERRAL_REWARD); ?> for each friend who joins</div>
                    <button class="refer-btn" onclick="showReferralCode()">Refer & Earn</button>
                </div>
            <?php endif; ?>
        </div>
        
        <?php if ($loggedIn): ?>
            <div class="footer">
                <a href="index.php" class="footer-btn">
                    <div class="footer-icon">🏠</div>
                    <div>Home</div>
                </a>
                <a href="earn.php" class="footer-btn">
                    <div class="footer-icon">💰</div>
                    <div>Earn</div>
                </a>
                <a href="withdraw.php" class="footer-btn">
                    <div class="footer-icon">💳</div>
                    <div>Withdraw</div>
                </a>
                <a href="profile.php" class="footer-btn">
                    <div class="footer-icon">👤</div>
                    <div>Profile</div>
                </a>
            </div>
        <?php endif; ?>
    </div>
    
    <script>
        function completeTask(taskId) {
            fetch('complete_task.php', {
                method: 'POST',
                headers: {
                    'Content-Type': 'application/x-www-form-urlencoded',
                },
                body: 'task_id=' + taskId
            })
            .then(response => response.json())
            .then(data => {
                if (data.success) {
                    alert('Task completed! You earned ' + data.amount);
                    location.reload();
                } else {
                    alert(data.message || 'Error completing task');
                }
            })
            .catch(error => {
                console.error('Error:', error);
                alert('An error occurred');
            });
        }
        
        function showReferralCode() {
            alert('Your referral code: <?php echo $user['referral_code'] ?? ''; ?>\n\nShare this code with friends to earn more!');
        }
    </script>
</body>
</html>