<?php
require_once 'config.php';

// Check if user is logged in
if (!isset($_SESSION['telegram_user'])) {
    header("Location: index.php");
    exit();
}

$telegramId = $_SESSION['telegram_user']['id'];

// Get user data
try {
    $stmt = $pdo->prepare("SELECT * FROM users WHERE telegram_id = ?");
    $stmt->execute([$telegramId]);
    $user = $stmt->fetch(PDO::FETCH_ASSOC);
    
    if (!$user) {
        header("Location: logout.php");
        exit();
    }
    
    // Get balance
    $balance = $user['balance'];
    
    // Get total earnings
    $stmt = $pdo->prepare("SELECT SUM(amount) as total FROM earnings WHERE user_id = ?");
    $stmt->execute([$user['id']]);
    $totalEarnings = $stmt->fetch(PDO::FETCH_ASSOC)['total'] ?? 0;
    
    // Get ads watched
    $stmt = $pdo->prepare("SELECT COUNT(*) as count FROM earnings WHERE user_id = ? AND source = 'ad'");
    $stmt->execute([$user['id']]);
    $adsWatched = $stmt->fetch(PDO::FETCH_ASSOC)['count'] ?? 0;
    
    // Get referrals count
    $stmt = $pdo->prepare("SELECT COUNT(*) as count FROM users WHERE referred_by = ?");
    $stmt->execute([$user['referral_code']]);
    $referralsCount = $stmt->fetch(PDO::FETCH_ASSOC)['count'] ?? 0;
    
    // Get referral earnings
    $stmt = $pdo->prepare("SELECT SUM(amount) as total FROM earnings WHERE user_id = ? AND source = 'referral'");
    $stmt->execute([$user['id']]);
    $referralEarnings = $stmt->fetch(PDO::FETCH_ASSOC)['total'] ?? 0;
    
} catch(PDOException $e) {
    die("Database error: " . $e->getMessage());
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>My Profile - Telegram Username Bot</title>
    <link href="https://fonts.googleapis.com/css2?family=Roboto:wght@300;400;500;700&display=swap" rel="stylesheet">
    <style>
        * {
            margin: 0;
            padding: 0;
            box-sizing: border-box;
            font-family: 'Roboto', sans-serif;
        }
        body {
            background-color: #f5f5f5;
            color: #333;
        }
        .container {
            max-width: 500px;
            margin: 0 auto;
            background: white;
            min-height: 100vh;
            position: relative;
        }
        .header {
            background-color: #0088cc;
            color: white;
            padding: 15px;
            text-align: center;
        }
        .logo {
            font-size: 20px;
            font-weight: bold;
        }
        .main-content {
            padding: 15px;
        }
        .profile-section {
            display: flex;
            align-items: center;
            margin-bottom: 20px;
        }
        .profile-pic {
            width: 80px;
            height: 80px;
            border-radius: 50%;
            background-color: #e6f7ff;
            display: flex;
            align-items: center;
            justify-content: center;
            margin-right: 15px;
            color: #0088cc;
            font-size: 36px;
            overflow: hidden;
        }
        .profile-pic img {
            width: 100%;
            height: 100%;
            object-fit: cover;
        }
        .profile-info {
            flex: 1;
        }
        .profile-name {
            font-weight: 500;
            font-size: 18px;
            margin-bottom: 5px;
        }
        .profile-username {
            color: #666;
            margin-bottom: 5px;
        }
        .profile-balance {
            font-weight: 500;
            color: #0088cc;
        }
        .stats-section {
            display: grid;
            grid-template-columns: 1fr 1fr;
            gap: 10px;
            margin-bottom: 20px;
        }
        .stat-card {
            background: white;
            border-radius: 10px;
            padding: 15px;
            box-shadow: 0 2px 5px rgba(0,0,0,0.1);
            text-align: center;
        }
        .stat-value {
            font-size: 20px;
            font-weight: 500;
            color: #0088cc;
            margin: 5px 0;
        }
        .stat-label {
            font-size: 14px;
            color: #666;
        }
        .referral-section {
            background: white;
            border-radius: 10px;
            padding: 15px;
            margin-bottom: 15px;
            box-shadow: 0 2px 5px rgba(0,0,0,0.1);
        }
        .section-title {
            font-weight: 500;
            margin-bottom: 10px;
        }
        .referral-code {
            background-color: #f0f0f0;
            padding: 10px;
            border-radius: 5px;
            font-family: monospace;
            font-size: 18px;
            text-align: center;
            margin: 10px 0;
        }
        .referral-instructions {
            font-size: 14px;
            color: #666;
            margin-bottom: 15px;
        }
        .refer-btn {
            background-color: #8e44ad;
            color: white;
            border: none;
            padding: 12px;
            border-radius: 5px;
            font-weight: 500;
            cursor: pointer;
            display: block;
            width: 100%;
            font-size: 16px;
        }
        .logout-btn {
            background-color: #e74c3c;
            color: white;
            border: none;
            padding: 12px;
            border-radius: 5px;
            font-weight: 500;
            cursor: pointer;
            display: block;
            width: 100%;
            font-size: 16px;
            margin-top: 15px;
        }
        .footer {
            position: fixed;
            bottom: 0;
            width: 100%;
            max-width: 500px;
            background-color: #0088cc;
            display: flex;
            justify-content: space-around;
            padding: 10px 0;
        }
        .footer-btn {
            color: white;
            text-decoration: none;
            text-align: center;
            font-size: 12px;
        }
        .footer-icon {
            font-size: 20px;
            margin-bottom: 5px;
        }
    </style>
</head>
<body>
    <div class="container">
        <div class="header">
            <div class="logo">My Profile</div>
        </div>
        
        <div class="main-content">
            <div class="profile-section">
                <div class="profile-pic">
                    <?php if (isset($_SESSION['telegram_user']['photo_url'])): ?>
                        <img src="<?php echo htmlspecialchars($_SESSION['telegram_user']['photo_url']); ?>" alt="Profile Photo">
                    <?php else: ?>
                        👤
                    <?php endif; ?>
                </div>
                <div class="profile-info">
                    <div class="profile-name"><?php echo htmlspecialchars($user['full_name']); ?></div>
                    <div class="profile-username">@<?php echo htmlspecialchars($user['username']); ?></div>
                    <div class="profile-balance">Balance: <?php echo formatCurrency($balance); ?></div>
                </div>
            </div>
            
            <div class="stats-section">
                <div class="stat-card">
                    <div class="stat-value"><?php echo formatCurrency($totalEarnings); ?></div>
                    <div class="stat-label">Total Earnings</div>
                </div>
                <div class="stat-card">
                    <div class="stat-value"><?php echo $adsWatched; ?></div>
                    <div class="stat-label">Ads Watched</div>
                </div>
                <div class="stat-card">
                    <div class="stat-value"><?php echo $referralsCount; ?></div>
                    <div class="stat-label">Referrals</div>
                </div>
                <div class="stat-card">
                    <div class="stat-value"><?php echo formatCurrency($referralEarnings); ?></div>
                    <div class="stat-label">Referral Earnings</div>
                </div>
            </div>
            
            <div class="referral-section">
                <div class="section-title">Refer Friends & Earn</div>
                <div class="referral-instructions">
                    Share your referral code with friends and earn <?php echo formatCurrency(REFERRAL_REWARD); ?> for each friend who joins and starts earning!
                </div>
                <div class="referral-code"><?php echo $user['referral_code']; ?></div>
                <button class="refer-btn" onclick="shareReferralCode()">Share Referral Code</button>
            </div>
            
            <button class="logout-btn" onclick="window.location.href='logout.php'">Logout</button>
        </div>
        
        <div class="footer">
            <a href="index.php" class="footer-btn">
                <div class="footer-icon">🏠</div>
                <div>Home</div>
            </a>
            <a href="earn.php" class="footer-btn">
                <div class="footer-icon">💰</div>
                <div>Earn</div>
            </a>
            <a href="withdraw.php" class="footer-btn">
                <div class="footer-icon">💳</div>
                <div>Withdraw</div>
            </a>
            <a href="profile.php" class="footer-btn">
                <div class="footer-icon">👤</div>
                <div>Profile</div>
            </a>
        </div>
    </div>
    
    <script>
        function shareReferralCode() {
            const referralCode = '<?php echo $user['referral_code']; ?>';
            const message = `Join Telegram Username Bot using my referral code ${referralCode} and start earning money!`;
            
            if (navigator.share) {
                navigator.share({
                    title: 'Join Telegram Username Bot',
                    text: message,
                    url: window.location.href
                }).catch(err => {
                    console.log('Error sharing:', err);
                    copyToClipboard(message);
                });
            } else {
                copyToClipboard(message);
            }
        }
        
        function copyToClipboard(text) {
            const textarea = document.createElement('textarea');
            textarea.value = text;
            document.body.appendChild(textarea);
            textarea.select();
            document.execCommand('copy');
            document.body.removeChild(textarea);
            alert('Referral message copied to clipboard: ' + text);
        }
    </script>
</body>
</html>